#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ipython-kernel
version:              0.12.0.0
visibility:           public
id:                   ipython-kernel-0.12.0.0-8eqPEnNXCprBg3XLGWc1d1
key:                  ipython-kernel-0.12.0.0-8eqPEnNXCprBg3XLGWc1d1
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A library for creating kernels for IPython frontends
description:
    ipython-kernel is a library for communicating with frontends for the interactive IPython framework. It is used extensively in IHaskell, the interactive Haskell environment.

category:             Development
abi:                  f4df57b702ebd9bd79434aa3b801b523
exposed:              True
exposed-modules:
    IHaskell.IPython.EasyKernel IHaskell.IPython.Kernel
    IHaskell.IPython.Message.Parser IHaskell.IPython.Message.UUID
    IHaskell.IPython.Types IHaskell.IPython.ZeroMQ

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ipython-kernel-0.12.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ipython-kernel-0.12.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ipython-kernel-0.12.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipython-kernel
hs-libraries:         HSipython-kernel-0.12.0.0-8eqPEnNXCprBg3XLGWc1d1
depends:
    aeson-2.2.2.0-1j2UQRt1mV1Loqrh8KvmRL base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-9uI0fkbeIJSAnQFs1F8d4F directory-1.3.8.5
    filepath-1.4.300.1 memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    parsec-3.1.16.1 process-1.6.19.0
    temporary-1.3-9rcNesEzN8L9Jsn9e228tO text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-2pZfUb3hQF1KSawFItMd4V
    uuid-1.3.16.1-B8dHM40up0W32eC5wrEUud
    zeromq4-haskell-0.8.0-66GEST4dHl67qOFDzEX7rl

haddock-interfaces:
    /usr/share/doc/haskell-ipython-kernel/html/ipython-kernel.haddock

haddock-html:         /usr/share/doc/haskell-ipython-kernel/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

